==> openttd-1.9.0-beta1-docs.tar.tar: openttd-1.9.0-beta1-docs/html/d9/df0/classCYapfDestinationTileRoadT.js <==
var classCYapfDestinationTileRoadT =
[
    [ "Key", "d9/df0/classCYapfDestinationTileRoadT.html#a48ae8732ae34a460d8f533c06cb5bace", null ],
    [ "Node", "d9/df0/classCYapfDestinationTileRoadT.html#a7098e657db7b0c9ee81fd706cd7b3266", null ],
    [ "Tpf", "d9/df0/classCYapfDestinationTileRoadT.html#a322a31cbdc2d22ae24bc78a3ed9dbeb1", null ],
    [ "TrackFollower", "d9/df0/classCYapfDestinationTileRoadT.html#a3bdd8c0dbde63bf32d96901b2519a666", null ],
    [ "PfCalcEstimate", "d9/df0/classCYapfDestinationTileRoadT.html#a0f67c9617e697866fe44b98a488a77eb", null ],
    [ "PfDetectDestination", "d9/df0/classCYapfDestinationTileRoadT.html#ae04b021a31c10cf44d24e5e109ed3e78", null ],
    [ "PfDetectDestinationTile", "d9/df0/classCYapfDestinationTileRoadT.html#a396223c0f8286bf7241e9ea37128bd18", null ],
    [ "SetDestination", "d9/df0/classCYapfDestinationTileRoadT.html#a111dd6e53320027fbfe89829b411faa0", null ],
    [ "Yapf", "d9/df0/classCYapfDestinationTileRoadT.html#a8db28b40ac8906a8cd820c6c704e0e21", null ],
    [ "m_bus", "d9/df0/classCYapfDestinationTileRoadT.html#a600f38db9d82a6d0e7bae5d771f6662c", null ],
    [ "m_dest_station", "d9/df0/classCYapfDestinationTileRoadT.html#ae4c16d7ab9159d8f36d0de94e4dfadfa", null ],
    [ "m_destTile", "d9/df0/classCYapfDestinationTileRoadT.html#a701dd77741635bff40fc59f9ae7de650", null ],
    [ "m_destTrackdirs", "d9/df0/classCYapfDestinationTileRoadT.html#ae834b9cdd8880142291a91ec71ea69a0", null ],
    [ "m_non_artic", "d9/df0/classCYapfDestinationTileRoadT.html#a0efc0be8ba294240b74d6d219a0a4716", null ]
];

==> openttd-1.11.0-beta1-docs.tar.tar: openttd-1.11.0-beta1-docs/html/d9/df0/classCYapfDestinationTileRoadT.js <==
var classCYapfDestinationTileRoadT =
[
    [ "Key", "d9/df0/classCYapfDestinationTileRoadT.html#a48ae8732ae34a460d8f533c06cb5bace", null ],
    [ "Node", "d9/df0/classCYapfDestinationTileRoadT.html#a7098e657db7b0c9ee81fd706cd7b3266", null ],
    [ "Tpf", "d9/df0/classCYapfDestinationTileRoadT.html#a322a31cbdc2d22ae24bc78a3ed9dbeb1", null ],
    [ "TrackFollower", "d9/df0/classCYapfDestinationTileRoadT.html#a3bdd8c0dbde63bf32d96901b2519a666", null ],
    [ "GetDestinationStation", "d9/df0/classCYapfDestinationTileRoadT.html#aa925cafa836f6ebe3d26c7e75031db79", null ],
    [ "PfCalcEstimate", "d9/df0/classCYapfDestinationTileRoadT.html#a0f67c9617e697866fe44b98a488a77eb", null ],
    [ "PfDetectDestination", "d9/df0/classCYapfDestinationTileRoadT.html#ae04b021a31c10cf44d24e5e109ed3e78", null ],
    [ "PfDetectDestinationTile", "d9/df0/classCYapfDestinationTileRoadT.html#a396223c0f8286bf7241e9ea37128bd18", null ],
    [ "SetDestination", "d9/df0/classCYapfDestinationTileRoadT.html#a111dd6e53320027fbfe89829b411faa0", null ],
    [ "Yapf", "d9/df0/classCYapfDestinationTileRoadT.html#a8db28b40ac8906a8cd820c6c704e0e21", null ],
    [ "m_bus", "d9/df0/classCYapfDestinationTileRoadT.html#a600f38db9d82a6d0e7bae5d771f6662c", null ],
    [ "m_dest_station", "d9/df0/classCYapfDestinationTileRoadT.html#ae4c16d7ab9159d8f36d0de94e4dfadfa", null ],
    [ "m_destTile", "d9/df0/classCYapfDestinationTileRoadT.html#a701dd77741635bff40fc59f9ae7de650", null ],
    [ "m_destTrackdirs", "d9/df0/classCYapfDestinationTileRoadT.html#ae834b9cdd8880142291a91ec71ea69a0", null ],
    [ "m_non_artic", "d9/df0/classCYapfDestinationTileRoadT.html#a0efc0be8ba294240b74d6d219a0a4716", null ]
];
